*-----------------------------------------------------------------------------------*

*                              数字政府鸿沟与收入差距                               *

*-----------------------------------------------------------------------------------*

clear all

set more off

cd " 指定路径 "

*-----------------------------------------------------------------------------------*

use "数字政府与收入差距公开数据集", clear 

global control "lnpergdp lnpergdpse popgrowth induemp urbanrate opennew "

//生成出生率*时间趋势项的IV
gen yeartrend=2 if year==2002
replace yeartrend=3 if year==2003
replace yeartrend=4 if year==2004
replace yeartrend=7 if year==2007
replace yeartrend=9 if year==2009
replace yeartrend=11 if year==2011
replace yeartrend=13 if year==2013
replace yeartrend=15 if year==2015
replace yeartrend=17 if year==2017
replace yeartrend=19 if year==2019

gen IVtrend=Y1950_55*yeartrend
gen SEIVtrend=(Y1950_55^2)*yeartrend

global BirIV "IVtrend"
global SEBirIV "SEIVtrend"


//表1 描述性统计
bys countryid: egen pannum=count(gini_disp) if year>2005
gen EGDIse=EGDI_up^2

logout, save(sum) word excel replace: sum gini_disp gini_mkt EGDI_up EGDIse Y1950_55 $control if gini_mkt!=. & year>2005 & lnpergdp!=.

//表2-再分配的结果OLS
xtset countryid year

xtreg gini_disp EGDI_up EGDIse i.year  if year>2005 & lnpergdp!=. & induemp!=., fe vce(cluster countryid)
est store a1
xtreg gini_disp EGDI_up EGDIse $control i.year if year>2005, fe vce(cluster countryid)
est store a2
xtreg disp5 EGDI_up EGDIse $control i.year if year>2005, fe vce(cluster countryid)
est store a3
xtreg disp3 EGDI_up EGDIse $control i.year if year>2005, fe vce(cluster countryid)
est store a4
outreg2 [a1 a2 a3 a4] using 再分配结果OLS, word replace bdec(4) sdec(4)

//表3-再分配的结果IV
ivreghdfe gini_disp (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & lnpergdp!=. & induemp!=. , absorb(year countryid) first endog(EGDI_up EGDIse) cluster(countryid)
est store b1
ivreghdfe gini_disp $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster(countryid)
est store b2
ivreghdfe disp5 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster(countryid)
est store b3
ivreghdfe disp3 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster(countryid)
est store b4
outreg2 [b1 b2 b3 b4] using 再分配结果IV, word replace bdec(3) sdec(3)

//表4-更换变量度量方式的稳健性检验
gen OSIse=OSI_up^2
gen OSEP1=0.5*OSI_up+0.5*EPI_up
gen OSEPse1=OSEP1^2
gen OSEP2=0.7*OSI_up+0.3*EPI_up
gen OSEPse2=OSEP2^2
gen OSEP3=0.3*OSI_up+0.7*EPI_up
gen OSEPse3=OSEP3^2

ivreghdfe gini_disp $control (OSI_up OSIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(OSI_up OSIse) cluster (countryid)
est store c1
ivreghdfe gini_disp $control (OSEP1 OSEPse1=$BirIV $SEBirIV) if year>2005 , absorb(year countryid) first endog(OSEP1 OSEPse1) cluster (countryid)
est store c2
ivreghdfe gini_disp $control (OSEP2 OSEPse2=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(OSEP2 OSEPse2) cluster (countryid)
est store c3
ivreghdfe gini_disp $control (OSEP3 OSEPse3=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(OSEP3 OSEPse3) cluster (countryid)
est store c4
outreg2 [c1 c2 c3 c4] using 更换变量度量方式的IV, word replace bdec(3) sdec(3)

//表5-模型设定的稳健性检验
ivreghdfe gini_disp $control (EGDI_up EGDIse=$BirIV $SEBirIV), absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store d1
ivreghdfe gini_disp $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & pannum==7, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store d2
ivreghdfe disp5 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & pannum==7, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store d3
ivreghdfe disp3 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & pannum==7, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store d4
outreg2 [d1 d2 d3 d4] using 再分配结果模型IV, word replace bdec(3) sdec(3)

//表6-加入更多控制变量
ivreghdfe gini_disp inflation $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store e1
ivreghdfe gini_disp fdiinflow $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store e2
ivreghdfe gini_disp polity $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store e3
ivreghdfe gini_disp leaderchange $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store e4
ivreghdfe gini_disp CPIscore $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store e5
ivreghdfe gini_disp inflation fdiinflow polity leaderchange CPIscore $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store e6
outreg2 [e1 e2 e3 e4 e5 e6] using 再分配结果更多控制IV, word replace bdec(3) sdec(3)

//表7-排他性的论证
ivreghdfe gini_disp csh_i $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 , absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store f1
ivreghdfe gini_disp healthrate $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 , absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store f2
ivreghdfe gini_disp socialprorate $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 , absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store f3
ivreghdfe gini_disp csh_i healthrate socialprorate $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 , absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store f4
outreg2 [f1 f2 f3 f4] using 排他性, word replace bdec(3) sdec(3)

//表8-机制
ivreghdfe gini_mkt (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005& lnpergdp!=. & induemp!=., absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store g1
ivreghdfe gini_mkt $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store g2
ivreghdfe mkt5 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store g3
ivreghdfe mkt3 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store g4
outreg2 [g1 g2 g3 g4] using 初次分配IV, word replace bdec(3) sdec(3)

//表9-异质性分析
gen incomdx=1 if incomeid==1 | incomeid==2
replace incomdx=2 if incomeid==3 | incomeid==4

ivreghdfe gini_disp $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & incomdx==1, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid) //低和中低
est store h1
ivreghdfe gini_disp $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & incomdx==2, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid) //高和中高
est store h2
ivreghdfe gini_disp $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & rr==1, absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store h3
ivreghdfe gini_disp $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & rr==0 , absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store h4
outreg2 [h1 h2 h3 h4] using 异质性IV, word replace bdec(3) sdec(3)

//表10-进一步分析对不同人群影响
ivreghdfe Highest20 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & gini_disp!=., absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store j1
ivreghdfe Second20 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & gini_disp!=., absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store j2
ivreghdfe Third20 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & gini_disp!=., absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store j3
ivreghdfe Forth20 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & gini_disp!=., absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store j4
ivreghdfe Lowest20 $control (EGDI_up EGDIse=$BirIV $SEBirIV) if year>2005 & gini_disp!=., absorb(year countryid) first endog(EGDI_up EGDIse) cluster (countryid)
est store j5
outreg2 [j1 j2 j3 j4 j5] using 不同人群IV, word replace bdec(3) sdec(3)

*------------------------------------------------end------------------------------------------------------*
